@@ -1,9 +1,12 @@
 from types import SimpleNamespace
 try:
-    import bpy
+    import bpy, mathutils
 except:
     # For type annotations
     bpy = SimpleNamespace(types=SimpleNamespace(
                             Scene=None,
                             Object=None,
-                            Mesh=None))
\ No newline at end of file
+                            Mesh=None))
+
+    mathutils = SimpleNamespace(Vector=SimpleNamespace(
+                            Euler=None))                            
\ No newline at end of file
